TipDistMatrix

Struct TipDistMatrix 

pub struct TipDistMatrix {
    pub ids: Vec<String>,
    pub data: Vec<f64>,
    /* private fields */
}
Symmetric patristic distance matrix with tip labels in skbio’s postorder tip order. data is row-major n×n.

Fields

ids: Vec<String>data: Vec<f64>

Implementations

Source

impl TipDistMatrix

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get(&self, i: usize, j: usize) -> f64

pub fn write_lsmat<W: Write>(&self, w: &mut W) -> Result<()>

Write the matrix in skbio DistanceMatrix.write (lsmat) TSV form: a header row starting with a tab then the ids, then one labelled row per tip. Values use CPython repr float formatting, byte-identical to skbio.